pub trait BiLinOp<T: ComplexField>: LinOp<T> {
// Required methods
fn transpose_apply_scratch(&self, rhs_ncols: usize, par: Par) -> StackReq;
fn transpose_apply(
&self,
out: MatMut<'_, T>,
rhs: MatRef<'_, T>,
par: Par,
stack: &mut MemStack,
);
fn adjoint_apply(
&self,
out: MatMut<'_, T>,
rhs: MatRef<'_, T>,
par: Par,
stack: &mut MemStack,
);
}Expand description
linear operator that can be applied from either the right or the left side
Required Methods
Sourcefn transpose_apply_scratch(&self, rhs_ncols: usize, par: Par) -> StackReq
fn transpose_apply_scratch(&self, rhs_ncols: usize, par: Par) -> StackReq
computes the workspace size and alignment required to apply the transpose or adjoint o
self to a matrix with rhs_ncols columns